@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::ygrok;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 # ABSTRACT: Parse lines of text into documents
 
 use ETL::Yertl;
@@ -161,13 +161,13 @@ sub main {
                     say $pattern;
                 }
                 else {
-                    my $out_fmt = load_module( format => 'default' )->new;
+                    my $out_fmt = ETL::Yertl::Format->get_default;
                     say $out_fmt->format( $pattern );
                 }
             }
             else {
                 # Show all patterns we know about
-                my $out_fmt = load_module( format => 'default' )->new;
+                my $out_fmt = ETL::Yertl::Format->get_default;
                 say $out_fmt->format( $patterns );
             }
         }
@@ -186,7 +186,9 @@ sub main {
 
     my $loop = IO::Async::Loop->new;
 
-    my $out = ETL::Yertl::FormatStream->new_for_stdout;
+    my $out = ETL::Yertl::FormatStream->new_for_stdout(
+        autoflush => 1,
+    );
     $loop->add( $out );
 
     push @files, "-" unless @files;
@@ -313,7 +315,7 @@ ETL::Yertl::Command::ygrok - Parse lines of text into documents
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 AUTHOR
 
