@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::ysql;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 # ABSTRACT: Read and write documents with a SQL database
 
 use ETL::Yertl;
@@ -282,7 +282,7 @@ sub config {
     my $conf_file = path( File::HomeDir->my_home, '.yertl', 'ysql.yml' );
     my $config;
     if ( $conf_file->exists ) {
-        ( $config ) = docs_from_string( $conf_file->slurp );
+        ( $config ) = docs_from_string( yaml => $conf_file->slurp );
     }
     return $config || {};
 }
@@ -347,7 +347,7 @@ ETL::Yertl::Command::ysql - Read and write documents with a SQL database
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 AUTHOR
 
