@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::yts;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 # ABSTRACT: Read/Write time series data
 
 #pod =head1 SYNOPSIS
@@ -92,7 +92,7 @@ sub main {
     # Read metrics
     else {
         die "Must give a metric\n" unless $metric;
-        my $out_fmt = load_module( format => 'default' )->new;
+        my $out_fmt = ETL::Yertl::Format->get_default;
         my @points = $db->read_ts( {
             metric => $metric,
             tags => $opt{tags},
@@ -123,7 +123,7 @@ ETL::Yertl::Command::yts - Read/Write time series data
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
